@@ -1,11 +1,12 @@
-app.directive('addressbook', function() {
+angular.module('contactsApp')
+.directive('addressbook', function() {
 	return {
 		restrict: 'A', // has to be an attribute to work with core css
 		scope: {},
 		controller: 'addressbookCtrl',
 		controllerAs: 'ctrl',
 		bindToController: {
-			addressBook: "=data"
+			addressBook: '=data'
 		},
 		templateUrl: OC.linkTo('contacts', 'templates/addressBook.html')
 	};
