@@ -4,9 +4,12 @@ OC.L10N.register(
     "Contacts" : "Kontakter",
     "No contacts in here" : "Ingen kontaktpersoner her",
     "Name" : "Navn",
+    "Organization" : "Organisation",
+    "Title" : "Titel",
     "Add field ..." : "Tilføj felt...",
     "Add contact" : "Tilføj kontaktpeson.",
     "All contacts" : "Alle kontakter",
+    "Not grouped" : "Ikke i gruppe",
     "Postal Code" : "Postnummer",
     "City" : "By",
     "State or province" : "Stat eller provins",
@@ -14,11 +17,8 @@ OC.L10N.register(
     "Address" : "Adresse",
     "{addressbook} shared by {owner}" : "{addressbook} delt af {owner}",
     "Nickname" : "Kaldenavn",
-    "Organization" : "Organisation",
     "Notes" : "Noter",
     "Website" : "Hjemmeside",
-    "Title" : "Titel",
-    "Role" : "Rolle",
     "Federated Cloud ID" : "Federated Cloud ID",
     "Home" : "Hjemme",
     "Work" : "Arbejde",
@@ -33,6 +33,8 @@ OC.L10N.register(
     "Fax home" : "Fax hjemme",
     "Fax work" : "Fax arbejde",
     "Pager" : "Personsøger",
-    "Voice" : "Telefonsvarer"
+    "Voice" : "Telefonsvarer",
+    "Settings" : "Indstillinger",
+    "Import" : "Importér"
 },
 "nplurals=2; plural=(n != 1);");
