@@ -2,24 +2,27 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Kontakte",
+    "Address book name" : "Adressbuch Name",
     "No contacts in here" : "Keine Kontakte gefunden",
     "Name" : "Name",
+    "Organization" : "Organisation",
+    "Title" : "Titel",
     "Add field ..." : "Feld hinzufügen ...",
     "Add contact" : "Kontakt hinzufügen",
+    "No search result for {query}" : "Kein Ergebnis für {query}",
     "All contacts" : "Alle Kontakte",
+    "Not grouped" : "Nicht gruppiert",
     "Post Office Box" : "Briefkasten",
     "Postal Code" : "Postleitzahl",
     "City" : "Stadt",
     "State or province" : "Staat oder Provinz",
     "Country" : "Land",
     "Address" : "Adresse",
+    "(new group)" : "(neue Gruppe)",
     "{addressbook} shared by {owner}" : "{addressbook} geteilt von {owner}",
     "Nickname" : "Spitzname",
-    "Organization" : "Organisation",
     "Notes" : "Notizen",
     "Website" : "Website",
-    "Title" : "Titel",
-    "Role" : "Rolle",
     "Federated Cloud ID" : "Federated-Cloud-ID",
     "Home" : "Home",
     "Work" : "Arbeit",
@@ -34,6 +37,8 @@ OC.L10N.register(
     "Fax home" : "Fax persönlich",
     "Fax work" : "Fax geschäftlich",
     "Pager" : "Pager",
-    "Voice" : "Anruf"
+    "Voice" : "Anruf",
+    "Settings" : "Einstellungen",
+    "Import" : "Importieren"
 },
 "nplurals=2; plural=(n != 1);");
