@@ -2,20 +2,24 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Επαφές",
+    "Address book name" : "Όνομα βιβλίου διευθύνσεων",
     "No contacts in here" : "Δεν υπάρχουν επαφές εδώ",
     "Name" : "Όνομα",
+    "Organization" : "Οργανισμός",
+    "Title" : "Τίτλος",
+    "Add field ..." : "Προσθήκη πεδίου...",
     "Add contact" : "Προσθήκη επαφής",
     "All contacts" : "Όλες οι επαφές",
+    "Not grouped" : "Οχι ομαδοποιημένα",
+    "Postal Code" : "Ταχυδρομικός Κωδικός",
     "City" : "Πόλη",
     "State or province" : "Νομός ή περιφέρεια",
     "Country" : "Χώρα",
     "Address" : "Διεύθυνση",
     "{addressbook} shared by {owner}" : "Το {addressbook} διαμοιράστηκε από τον/την {owner}",
     "Nickname" : "Παρατσούκλι",
-    "Organization" : "Οργανισμός",
     "Notes" : "Σημειώσεις",
     "Website" : "Ιστοσελίδα",
-    "Title" : "Τίτλος",
     "Federated Cloud ID" : "Federated Cloud ID",
     "Home" : "Σπίτι",
     "Work" : "Εργασία",
@@ -28,6 +32,8 @@ OC.L10N.register(
     "Mobile" : "Κινητό",
     "Fax" : "Φαξ",
     "Pager" : "Βομβητής",
-    "Voice" : "Ομιλία"
+    "Voice" : "Ομιλία",
+    "Settings" : "Ρυθμίσεις",
+    "Import" : "Εισαγωγή"
 },
 "nplurals=2; plural=(n != 1);");
