@@ -4,22 +4,24 @@ OC.L10N.register(
     "Contacts" : "Contacts",
     "No contacts in here" : "No contacts in here",
     "Name" : "Name",
+    "Organization" : "Organisation",
+    "Title" : "Title",
     "Add field ..." : "Add field ...",
     "Add contact" : "Add contact",
+    "No search result for {query}" : "No search result for {query}",
     "All contacts" : "All contacts",
+    "Not grouped" : "Not grouped",
     "Post Office Box" : "Post Office Box",
     "Postal Code" : "Postal Code",
     "City" : "City",
     "State or province" : "State or province",
     "Country" : "Country",
     "Address" : "Address",
+    "(new group)" : "(new group)",
     "{addressbook} shared by {owner}" : "{addressbook} shared by {owner}",
     "Nickname" : "Nickname",
-    "Organization" : "Organisation",
     "Notes" : "Notes",
     "Website" : "Website",
-    "Title" : "Title",
-    "Role" : "Role",
     "Federated Cloud ID" : "Federated Cloud ID",
     "Home" : "Home",
     "Work" : "Work",
@@ -34,6 +36,8 @@ OC.L10N.register(
     "Fax home" : "Fax home",
     "Fax work" : "Fax work",
     "Pager" : "Pager",
-    "Voice" : "Voice"
+    "Voice" : "Voice",
+    "Settings" : "Settings",
+    "Import" : "Import"
 },
 "nplurals=2; plural=(n != 1);");
