@@ -4,9 +4,12 @@ OC.L10N.register(
     "Contacts" : "Contactos",
     "No contacts in here" : "No hay contactos aquí",
     "Name" : "Nombre",
+    "Organization" : "Organización",
+    "Title" : "Título",
     "Add field ..." : "Añadiendo campo ...",
     "Add contact" : "Añadir contacto",
     "All contacts" : "Todos los contactos",
+    "Not grouped" : "No agrupado",
     "Post Office Box" : "Buzón de correo",
     "Postal Code" : "Código Postal",
     "City" : "Ciudad",
@@ -15,11 +18,8 @@ OC.L10N.register(
     "Address" : "Dirección",
     "{addressbook} shared by {owner}" : "{addressbook} compartido por {owner}",
     "Nickname" : "Apodo",
-    "Organization" : "Organización",
     "Notes" : "Notas",
     "Website" : "Sitio web",
-    "Title" : "Título",
-    "Role" : "Rol",
     "Federated Cloud ID" : "ID Nube Federada",
     "Home" : "Inicio",
     "Work" : "Trabajo",
@@ -34,6 +34,8 @@ OC.L10N.register(
     "Fax home" : "nº de Fax",
     "Fax work" : "Fax del trabajo",
     "Pager" : "Localizador",
-    "Voice" : "Voz"
+    "Voice" : "Voz",
+    "Settings" : "Ajustes",
+    "Import" : "Importar"
 },
 "nplurals=2; plural=(n != 1);");
