@@ -4,22 +4,24 @@ OC.L10N.register(
     "Contacts" : "Yhteystiedot",
     "No contacts in here" : "Ei yhteytietoja",
     "Name" : "Nimi",
+    "Organization" : "Organisaatio",
+    "Title" : "Otsikko",
     "Add field ..." : "Lisää kenttä...",
     "Add contact" : "Lisää yhteystieto",
+    "No search result for {query}" : "Ei tuloksia haulle {query}",
     "All contacts" : "Kaikki yhteystiedot",
+    "Not grouped" : "Ei ryhmitelty",
     "Post Office Box" : "Postilokero",
     "Postal Code" : "Postinumero",
     "City" : "Paikkakunta",
     "State or province" : "Maakunta tai osavaltio",
     "Country" : "Maa",
     "Address" : "Osoite",
+    "(new group)" : "(uusi ryhmä)",
     "{addressbook} shared by {owner}" : "Osoitekirjan {addressbook} jakoi {owner}",
     "Nickname" : "Kutsumanimi",
-    "Organization" : "Organisaatio",
     "Notes" : "Huomiot",
     "Website" : "Verkkosivusto",
-    "Title" : "Otsikko",
-    "Role" : "Rooli",
     "Federated Cloud ID" : "Federoidun pilven tunniste",
     "Home" : "Koti",
     "Work" : "Työ",
@@ -34,6 +36,8 @@ OC.L10N.register(
     "Fax home" : "Faksi, koti",
     "Fax work" : "Faksi, työ",
     "Pager" : "Hakulaite",
-    "Voice" : "Ääni"
+    "Voice" : "Ääni",
+    "Settings" : "Asetukset",
+    "Import" : "Tuo"
 },
 "nplurals=2; plural=(n != 1);");
