@@ -4,22 +4,24 @@ OC.L10N.register(
     "Contacts" : "Contacts",
     "No contacts in here" : "Aucun contact",
     "Name" : "Nom",
+    "Organization" : "Société",
+    "Title" : "Titre",
     "Add field ..." : "Ajouter un champ ...",
     "Add contact" : "Ajouter un contact",
+    "No search result for {query}" : "Aucun résultat pour {query}",
     "All contacts" : "Tous les contacts",
+    "Not grouped" : "Non groupés",
     "Post Office Box" : "Boîte postale",
     "Postal Code" : "Code postal ",
     "City" : "Ville",
     "State or province" : "État ou région",
     "Country" : "Pays",
     "Address" : "Adresse",
+    "(new group)" : "(nouveau groupe)",
     "{addressbook} shared by {owner}" : "{addressbook} partagé par {owner}",
     "Nickname" : "Surnom",
-    "Organization" : "Société",
     "Notes" : "Notes",
     "Website" : "Site web",
-    "Title" : "Titre",
-    "Role" : "Rôle ",
     "Federated Cloud ID" : "Federated Cloud ID",
     "Home" : "Privé(e)",
     "Work" : "Pro",
@@ -34,6 +36,8 @@ OC.L10N.register(
     "Fax home" : "Fax personnel",
     "Fax work" : "Fax pro",
     "Pager" : "Bipeur",
-    "Voice" : "Voix"
+    "Voice" : "Voix",
+    "Settings" : "Paramètres",
+    "Import" : "Importer"
 },
 "nplurals=2; plural=(n > 1);");
