@@ -4,22 +4,24 @@ OC.L10N.register(
     "Contacts" : "אנשי קשר",
     "No contacts in here" : "אין כאן אנשי קשר",
     "Name" : "שם",
+    "Organization" : "ארגון",
+    "Title" : "כותרת",
     "Add field ..." : "הוספת שדה...",
     "Add contact" : "הוסף איש קשר",
+    "No search result for {query}" : "אין תוצאות חיפוש עבור {query}",
     "All contacts" : "כל אנשי הקשר",
+    "Not grouped" : "לא שויך לקבוצה",
     "Post Office Box" : "תיבת דואר",
     "Postal Code" : "מיקוד",
     "City" : "עיר",
     "State or province" : "מדינה או מחוז",
     "Country" : "מדינה",
     "Address" : "כתובת",
+    "(new group)" : "(קבוצה חדשה)",
     "{addressbook} shared by {owner}" : "{addressbook} שותף על ידי {owner}",
     "Nickname" : "כינוי",
-    "Organization" : "ארגון",
     "Notes" : "הערות",
     "Website" : "אתר אינטרנט",
-    "Title" : "כותרת",
-    "Role" : "תפקיד",
     "Federated Cloud ID" : "מספר זיהוי ענן מאוגד",
     "Home" : "בית",
     "Work" : "עבודה",
@@ -34,6 +36,8 @@ OC.L10N.register(
     "Fax home" : "פקס בבית",
     "Fax work" : "פקס בעבודה",
     "Pager" : "זימונית",
-    "Voice" : "קולי"
+    "Voice" : "קולי",
+    "Settings" : "הגדרות",
+    "Import" : "יבוא"
 },
 "nplurals=2; plural=(n != 1);");
