@@ -4,19 +4,25 @@ OC.L10N.register(
     "Contacts" : "Tengiliðir",
     "No contacts in here" : "Engir tengiliðir hér",
     "Name" : "Nafn",
+    "Organization" : "Stofnun/félag",
+    "Title" : "Titill",
+    "Add field ..." : "Bæta við reit...",
     "Add contact" : "Bæta við tengilið",
+    "No search result for {query}" : "Engar leitarniðurstöður fyrir {query}",
     "All contacts" : "Allir tengiliðir",
+    "Not grouped" : "Ekki hópað",
+    "Post Office Box" : "Pósthólf",
+    "Postal Code" : "Póstnúmer",
     "City" : "Borg",
     "State or province" : "Ríki eða fylki",
     "Country" : "Land",
     "Address" : "Slóð",
+    "(new group)" : "(nýr hópur)",
     "{addressbook} shared by {owner}" : "{addressbook} deilt af {owner}",
     "Nickname" : "Gælunafn",
-    "Organization" : "Stofnun/félag",
     "Notes" : "Minnispunktar",
     "Website" : "Vefsvæði",
-    "Title" : "Titill",
-    "Role" : "Hlutverk",
+    "Federated Cloud ID" : "Skýjasambandsauðkenni (Federated Cloud ID)",
     "Home" : "Heima",
     "Work" : "Vinna",
     "Other" : "Annað",
@@ -27,7 +33,11 @@ OC.L10N.register(
     "Phone" : "Sími",
     "Mobile" : "Farsími",
     "Fax" : "Fax",
+    "Fax home" : "Heimafax",
+    "Fax work" : "Vinnufax",
     "Pager" : "Símboði",
-    "Voice" : "Raddskilaboð"
+    "Voice" : "Raddskilaboð",
+    "Settings" : "Stillingar",
+    "Import" : "Flytja inn"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
