@@ -2,24 +2,27 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Contatti",
+    "Address book name" : "Nome della rubrica",
     "No contacts in here" : "Nessun contatto qui",
     "Name" : "Nome",
+    "Organization" : "Organizzazione",
+    "Title" : "Titolo",
     "Add field ..." : "Aggiungi campo...",
     "Add contact" : "Aggiungi contatto",
+    "No search result for {query}" : "Nessun risultato di ricerca per {query}",
     "All contacts" : "Tuuti i contatti",
+    "Not grouped" : "Non raggruppati",
     "Post Office Box" : "Casella postale",
     "Postal Code" : "CAP",
     "City" : "Città",
     "State or province" : "Stato o regione",
     "Country" : "Stato",
     "Address" : "Indirizzo",
+    "(new group)" : "(nuovo gruppo)",
     "{addressbook} shared by {owner}" : "{addressbook} condivisa da {owner}",
     "Nickname" : "Pseudonimo",
-    "Organization" : "Organizzazione",
     "Notes" : "Note",
     "Website" : "Sito web",
-    "Title" : "Titolo",
-    "Role" : "Ruolo",
     "Federated Cloud ID" : "ID di cloud federata",
     "Home" : "Home",
     "Work" : "Lavoro",
@@ -34,6 +37,8 @@ OC.L10N.register(
     "Fax home" : "Fax casa",
     "Fax work" : "Fax lavoro",
     "Pager" : "Cercapersone",
-    "Voice" : "Voce"
+    "Voice" : "Voce",
+    "Settings" : "Impostazioni",
+    "Import" : "Importa"
 },
 "nplurals=2; plural=(n != 1);");
