@@ -4,9 +4,12 @@ OC.L10N.register(
     "Contacts" : "연락처",
     "No contacts in here" : "여기에 연락처 없음",
     "Name" : "이름",
+    "Organization" : "조직",
+    "Title" : "제목",
     "Add field ..." : "필드 추가...",
     "Add contact" : "연락처 추가",
     "All contacts" : "모든 연락처",
+    "Not grouped" : "그룹에 없음",
     "Post Office Box" : "우편 사서함",
     "Postal Code" : "우편 번호",
     "City" : "도시",
@@ -15,11 +18,8 @@ OC.L10N.register(
     "Address" : "주소",
     "{addressbook} shared by {owner}" : "{owner} 님이 공유한 {addressbook}",
     "Nickname" : "별명",
-    "Organization" : "조직",
     "Notes" : "메모",
     "Website" : "웹 사이트",
-    "Title" : "제목",
-    "Role" : "지위",
     "Federated Cloud ID" : "연합 클라우드 ID",
     "Home" : "가정",
     "Work" : "직장",
@@ -32,6 +32,8 @@ OC.L10N.register(
     "Mobile" : "휴대폰",
     "Fax" : "팩스 번호",
     "Pager" : "호출기",
-    "Voice" : "음성 번호"
+    "Voice" : "음성 번호",
+    "Settings" : "설정",
+    "Import" : "가져오기"
 },
 "nplurals=1; plural=0;");
