@@ -4,22 +4,23 @@ OC.L10N.register(
     "Contacts" : "Kontakter",
     "No contacts in here" : "Ingen kontakter her",
     "Name" : "Navn",
+    "Organization" : "Organisasjon",
+    "Title" : "Tittel",
     "Add field ..." : "Nytt felt ...",
     "Add contact" : "Ny kontakt",
     "All contacts" : "Alle kontakter",
+    "Not grouped" : "Ikke gruppert",
     "Post Office Box" : "Postboks",
     "Postal Code" : "Postnummer",
     "City" : "By",
     "State or province" : "Stat eller fylke",
     "Country" : "Land",
     "Address" : "Adresse",
+    "(new group)" : "(ny gruppe)",
     "{addressbook} shared by {owner}" : "{addressbook} delt av {owner}",
     "Nickname" : "Kallenavn",
-    "Organization" : "Organisasjon",
     "Notes" : "Notater",
     "Website" : "Nettsted",
-    "Title" : "Tittel",
-    "Role" : "Rolle",
     "Federated Cloud ID" : "ID for sammenknyttet sky",
     "Home" : "Hjem",
     "Work" : "Jobb",
@@ -34,6 +35,8 @@ OC.L10N.register(
     "Fax home" : "Faks hjemme",
     "Fax work" : "Faks jobb",
     "Pager" : "Pager",
-    "Voice" : "Svarer"
+    "Voice" : "Svarer",
+    "Settings" : "Innstillinger",
+    "Import" : "Importer"
 },
 "nplurals=2; plural=(n != 1);");
