@@ -4,22 +4,24 @@ OC.L10N.register(
     "Contacts" : "Contactpersonen",
     "No contacts in here" : "Hier geen contactpersonen gevonden",
     "Name" : "Naam",
+    "Organization" : "Organisatie",
+    "Title" : "Titel",
     "Add field ..." : "Voeg veld toe",
     "Add contact" : "Contactpersoon toevoegen",
+    "No search result for {query}" : "Geen zoekresultaten voor {query}",
     "All contacts" : "Alle contactpersonen",
+    "Not grouped" : "Niet gegroepeerd",
     "Post Office Box" : "Postbus",
     "Postal Code" : "Postcode",
     "City" : "Stad",
     "State or province" : "Staat of provincie",
     "Country" : "Land",
     "Address" : "Adres",
+    "(new group)" : "(nieuwe groep)",
     "{addressbook} shared by {owner}" : "{addressbook} gedeeld door {owner}",
     "Nickname" : "Roepnaam",
-    "Organization" : "Organisatie",
     "Notes" : "Notities",
     "Website" : "Website",
-    "Title" : "Titel",
-    "Role" : "Rol",
     "Federated Cloud ID" : "Gefedereerde Cloud ID",
     "Home" : "Thuis",
     "Work" : "Werk",
@@ -34,6 +36,8 @@ OC.L10N.register(
     "Fax home" : "Fax thuis",
     "Fax work" : "Fax werk",
     "Pager" : "Pieper",
-    "Voice" : "Stem"
+    "Voice" : "Stem",
+    "Settings" : "Instellingen",
+    "Import" : "Importeer"
 },
 "nplurals=2; plural=(n != 1);");
