@@ -4,23 +4,25 @@ OC.L10N.register(
     "Contacts" : "Kontakty",
     "No contacts in here" : "Nie ma tu żadnych kontaktów",
     "Name" : "Nazwa",
+    "Organization" : "Organizacja",
+    "Title" : "Tytuł",
     "Add field ..." : "Dodaj pole ...",
     "Add contact" : "Dodaj kontakt",
+    "No search result for {query}" : "Brak wyników wyszukiwania dla zapytania {query}",
     "All contacts" : "Wszystkie kontakty",
+    "Not grouped" : "Nie zgrupowane",
     "Post Office Box" : "Skrytka Pocztowa",
     "Postal Code" : "Kod Pocztowy",
     "City" : "Miasto",
     "State or province" : "Województwo ",
     "Country" : "Kraj",
     "Address" : "Adres",
+    "(new group)" : "Nowa grupa",
     "{addressbook} shared by {owner}" : "Książka {addressbook} udostępniona przez {owner}",
     "Nickname" : "Nazwa",
-    "Organization" : "Organizacja",
     "Notes" : "Notatki",
     "Website" : "Strona www",
-    "Title" : "Tytuł",
-    "Role" : "Funkcja",
-    "Home" : "Dom",
+    "Home" : "Strona główna",
     "Work" : "Zawodowe",
     "Other" : "Inne",
     "Groups" : "Grupy",
@@ -33,6 +35,8 @@ OC.L10N.register(
     "Fax home" : "Faks domowy",
     "Fax work" : "Fakx pracowy",
     "Pager" : "Pager",
-    "Voice" : "Połączenie głosowe"
+    "Voice" : "Połączenie głosowe",
+    "Settings" : "Ustawienia",
+    "Import" : "Importuj"
 },
 "nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
