@@ -4,22 +4,24 @@ OC.L10N.register(
     "Contacts" : "Contatos",
     "No contacts in here" : "Nenhum contato aqui",
     "Name" : "Nome",
+    "Organization" : "Organização",
+    "Title" : "Título",
     "Add field ..." : "Adicionar campo...",
     "Add contact" : "Adicionar contatos",
+    "No search result for {query}" : "Nenhum resultado de busca para {query}",
     "All contacts" : "Todos os contatos",
+    "Not grouped" : "Não agrupado",
     "Post Office Box" : "Caixa de Correio",
     "Postal Code" : "Código Postal",
     "City" : "Cidade",
     "State or province" : "Estado ou província",
     "Country" : "País",
     "Address" : "Endereço",
+    "(new group)" : "(novo grupo)",
     "{addressbook} shared by {owner}" : "{addressbook} compartilhado por {owner}",
     "Nickname" : "Apelido",
-    "Organization" : "Organização",
     "Notes" : "Notas",
     "Website" : "Website",
-    "Title" : "Título",
-    "Role" : "Função",
     "Federated Cloud ID" : "ID de núvem Associada",
     "Home" : "Casa",
     "Work" : "Trabalho",
@@ -34,6 +36,8 @@ OC.L10N.register(
     "Fax home" : "Fax de casa",
     "Fax work" : "Fax do trabalho",
     "Pager" : "Pager",
-    "Voice" : "Voz"
+    "Voice" : "Voz",
+    "Settings" : "Configurações",
+    "Import" : "Importar"
 },
 "nplurals=2; plural=(n > 1);");
