@@ -4,20 +4,23 @@ OC.L10N.register(
     "Contacts" : "Contatos",
     "No contacts in here" : "Nenhum contato aqui",
     "Name" : "Nome",
+    "Organization" : "Organização",
+    "Title" : "Título ",
     "Add field ..." : "Adicionar campo ...",
     "Add contact" : "Adicionar contacto",
     "All contacts" : "Todos os contatos",
+    "Not grouped" : "Não agrupados",
+    "Post Office Box" : "Caixa Postal",
+    "Postal Code" : "Código Postal",
     "City" : "Cidade",
     "State or province" : "Distrito",
     "Country" : "País",
     "Address" : "Endereço",
+    "(new group)" : "(novo grupo)",
     "{addressbook} shared by {owner}" : "{addressbook} partilhado por {owner}",
     "Nickname" : "Alcunha",
-    "Organization" : "Organização",
     "Notes" : "Notas",
     "Website" : "Site da Internet",
-    "Title" : "Título ",
-    "Role" : "Papel",
     "Federated Cloud ID" : "Id. da Nuvem Federada",
     "Home" : "Início",
     "Work" : "Emprego",
@@ -29,7 +32,11 @@ OC.L10N.register(
     "Phone" : "Telefone",
     "Mobile" : "Telemóvel",
     "Fax" : "Fax",
+    "Fax home" : "Fax de casa",
+    "Fax work" : "Fax do emprego",
     "Pager" : "Pager",
-    "Voice" : "Voz"
+    "Voice" : "Voz",
+    "Settings" : "Definições",
+    "Import" : "Importar"
 },
 "nplurals=2; plural=(n != 1);");
