@@ -4,23 +4,25 @@ OC.L10N.register(
     "Contacts" : "Stiki",
     "No contacts in here" : "Ni dodanega nobenega stika!",
     "Name" : "Ime",
+    "Organization" : "Ustanova",
+    "Title" : "Naslov",
     "Add field ..." : "Dodaj polje ...",
     "Add contact" : "Dodaj stik",
+    "No search result for {query}" : "Ni zadetkov iskanja za {query}",
     "All contacts" : "Vsi stiki",
+    "Not grouped" : "Brez skupine",
     "Post Office Box" : "Poštni predal",
     "Postal Code" : "Poštna številka",
     "City" : "Mesto",
     "State or province" : "Zvezna država ali provinca",
     "Country" : "Država",
     "Address" : "Naslov",
+    "(new group)" : "(nova skupina)",
     "{addressbook} shared by {owner}" : "Souporabo imenika {addressbook} je omogočil uporabnik {owner}",
     "Nickname" : "Vzdevek",
-    "Organization" : "Ustanova",
     "Notes" : "Sporočilca",
     "Website" : "Spletna stran",
-    "Title" : "Naslov",
-    "Role" : "Vloga",
-    "Federated Cloud ID" : "ID Oblaka s prenosom dovoljenj",
+    "Federated Cloud ID" : "ID zveznega oblaka",
     "Home" : "Domači naslov",
     "Work" : "Službeni naslov",
     "Other" : "Drugo",
@@ -34,6 +36,8 @@ OC.L10N.register(
     "Fax home" : "Domači faks",
     "Fax work" : "Službeni faks",
     "Pager" : "Pozivnik",
-    "Voice" : "Glas"
+    "Voice" : "Glas",
+    "Settings" : "Nastavitve",
+    "Import" : "Uvozi"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
