@@ -4,22 +4,24 @@ OC.L10N.register(
     "Contacts" : "Kontakte",
     "No contacts in here" : "S’ka kontakte këtu",
     "Name" : "Emër",
+    "Organization" : "Organizëm",
+    "Title" : "Titull",
     "Add field ..." : "Shtoni fushë...",
     "Add contact" : "Shtoni kontakt",
+    "No search result for {query}" : "S’pat përfundime kërkimi për {query}",
     "All contacts" : "Krejt kontaktet",
+    "Not grouped" : "I pagrupuar",
     "Post Office Box" : "Kuti Zyre Postare",
     "Postal Code" : "Kod Postar",
     "City" : "Qytet",
     "State or province" : "Shtet ose provincë",
     "Country" : "Vend",
     "Address" : "Adresë",
+    "(new group)" : "(grup i ri)",
     "{addressbook} shared by {owner}" : "{addressbook} ndarë nga {owner}",
     "Nickname" : "Nofkë",
-    "Organization" : "Organizëm",
     "Notes" : "Shënime",
     "Website" : "Sajt",
-    "Title" : "Titull",
-    "Role" : "Rol",
     "Federated Cloud ID" : "ID Federated Cloud",
     "Home" : "Kreu",
     "Work" : "Pune",
@@ -34,6 +36,8 @@ OC.L10N.register(
     "Fax home" : "Faks shtëpie",
     "Fax work" : "Faks pune",
     "Pager" : "Faques",
-    "Voice" : "Zë"
+    "Voice" : "Zë",
+    "Settings" : "Rregullime",
+    "Import" : "Importoje"
 },
 "nplurals=2; plural=(n != 1);");
