@@ -4,22 +4,24 @@ OC.L10N.register(
     "Contacts" : "Kontakter",
     "No contacts in here" : "Det finns inga kontakter här",
     "Name" : "Namn",
+    "Organization" : "Organisation",
+    "Title" : "Rubrik",
     "Add field ..." : "Lägg till fält ...",
     "Add contact" : "Lägg till en kontakt",
+    "No search result for {query}" : "Inget sökresultat för {query}",
     "All contacts" : "Alla kontakter",
+    "Not grouped" : "Inte grupperad",
     "Post Office Box" : "Postbox",
     "Postal Code" : "Postkod",
     "City" : "Stad",
     "State or province" : "Stat eller provins",
     "Country" : "Land",
     "Address" : "Adress",
+    "(new group)" : "(ny grupp)",
     "{addressbook} shared by {owner}" : "{addressbook} delad av {owner}",
     "Nickname" : "Smeknamn",
-    "Organization" : "Organisation",
     "Notes" : "Anteckningar",
     "Website" : "Webbplats",
-    "Title" : "Rubrik",
-    "Role" : "Roll",
     "Federated Cloud ID" : "Federerad Cloud ID",
     "Home" : "Hem",
     "Work" : "Arbete",
@@ -34,6 +36,8 @@ OC.L10N.register(
     "Fax home" : "Fax hem",
     "Fax work" : "Fax arbete",
     "Pager" : "Personsökare",
-    "Voice" : "Röst"
+    "Voice" : "Röst",
+    "Settings" : "Inställningar",
+    "Import" : "Importera"
 },
 "nplurals=2; plural=(n != 1);");
